@@ -32,10 +32,16 @@ options( echo=FALSE)
   obj<- LKrig( x,y,NC=5, weights= weights, lambda=lambda,nlevel=nlevel,alpha=alpha,a.wght=a.wght,
                               NtrA=5,iseed=122)
   LKinfo<- obj$LKinfo
-# now check these formulas as implemented in LatticeKrig
-    obj0<- mKrig( x,y, weights= weights, lambda=lambda, m=2, cov.function="LKrig.cov",
+# The equivalent Kriging using mKrig and the LatticeKrig covariance function
+  obj0<- mKrig( x,y, weights= weights, lambda=lambda, m=2, cov.function="LKrig.cov",
                                  cov.args=list(LKinfo=LKinfo),
                                  NtrA=5, iseed=122)
+# quick up front test of likelihood computation
+# This is only valid if mKrig is computating the likelihood correctly ;-).  
+
+  test.for.zero( obj$lnProfileLike.FULL,obj0$lnProfileLike.FULL, 
+                 tag="lnProfileFULL from LKrig and identical compuation
+                 using mKrig")
  
 ###### check of formula with weights
   PHI<- as.matrix(LKrig.basis( x,LKinfo))
@@ -63,23 +69,41 @@ options( echo=FALSE)
                                  cov.args=list(LKinfo=LKinfo),
                                  NtrA=20, iseed=122)
   test.for.zero(  obj0$rho.MLE, obj$rho.MLE,
-                                tag="MLEs for rho with replicate fields" )
+           tag="MLEs for rho with replicate fields" )
 
   test.for.zero(  obj0$lnProfileLike, obj$lnProfileLike,
-                                tag="Profile Likelihood concentrated on lambda with replicate fields" )
+                tag="Profile Likelihood concentrated on lambda with replicate fields" )
+
+
 # test of full likelihood
-#    t(y- T%*%d.coef) %*% solve( sigma^2/w + rho*K)%*% y- T%*%d.coef)
-#  this is the quad form found from shortcut formula
-#
-   sigma<- .1
-   rho<- 2.2
-   lambda<- sigma^2/rho
+#    t(y- T%*%d.coef) %*% solve( sigma^2/w + rho*K) %*% ( y- T%*%d.coef)
+#    (1/rho) t(y- T%*%d.coef) %*% solve( lambda/w + K) %*% ( y- T%*%d.coef)
+#    (1/rho) * quad.form
+#  NOTE d.coef the MLE is GLS estimate and only depends on _lambda_ and not rho
+
+# small data set with reps and weights                                        #
+  data( ozone2)
+  x<-ozone2$lon.lat[1:20,]
+  y<- ozone2$y[16,1:20]
+  good <-  !is.na( y)
+  x<- x[good,]
+  y<- y[good]
+  N<- length( y)
+  set.seed(123)
+  weights<- runif(N)
+  W<- diag(weights)
+
+  sigma<- .1
+  rho<- 2.2
+  lambda<- sigma^2/rho
+
    obj.test<- LKrig( x,Y,NC=5, weights= weights, nlevel=nlevel,alpha=alpha,a.wght=a.wght,
                               NtrA=5,iseed=122, sigma=sigma, rho=rho)
    Tmatrix <- cbind(fields.mkpoly(x, 2))
    res<- Y - Tmatrix%*%obj.test$d.coef
+# the M matrix you have all been waiting for!
    M<- (diag(lambda/weights) + LKrig.cov(x,x,LKinfo=obj.test$LKinfo))
-   qtest<- diag( t(res)%*% solve( M)%*% res)
+   qtest<- diag( t(res)%*% solve( M)%*% res )
    test.for.zero( qtest, obj.test$quad.form, tag="quad form for arbitrary sigma and rho")
 
    n<- nrow( Y)
